==> v3.5.13.1.tar.gz: twin-style-crystal/client/myrootpixmap.h <==
/* vi: ts=8 sts=4 sw=4
 *
 * $Id: krootpixmap.h,v 1.15 2003/05/19 08:02:48 coolo Exp $
 * This file is part of the KDE project, module kdesktop.
 * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
 *
 * You can Freely distribute this program under the GNU Library General
 * Public License. See the file "COPYING.LIB" for the exact licensing terms.
 */

/* Modified by Sascha Hlusiak */
 

#ifndef __KRootPixmap_h_Included__
#define __KRootPixmap_h_Included__

#include <tqobject.h>
#include <tqcolor.h>

#ifndef TQ_WS_TQWS //FIXME

class TQRect;
class TQWidget;
class TQTimer;
class KSharedPixmap;
class KMyRootPixmapData;

class KMyRootPixmap: public TQObject
{
    Q_OBJECT
  TQ_OBJECT

public:
    KMyRootPixmap( TQWidget *target=NULL, const char *name=0 );

    KMyRootPixmap( TQWidget *target, TQObject *parent, const char *name=0 );

    virtual ~KMyRootPixmap();

    bool isAvailable();

    bool isActive() const { return m_bActive; }

    int currentDesktop() const;

//    bool customPainting() const { return m_bCustomPaint; }

#ifndef KDE_NO_COMPAT

    bool checkAvailable(bool) { return isAvailable(); }
#endif

public slots:
    virtual void start();

    virtual void stop();

//    void setFadeEffect(double strength, const TQColor &color);

    void repaint( bool force );

    void repaint();

//    void setCustomPainting( bool enable ) { m_bCustomPaint = enable; }

    void enableExports();

    static TQString pixmapName(int desk);
    
signals:
    void backgroundUpdated( const TQImage *pm );

protected:
//    virtual bool eventFilter(TQObject *, TQEvent *);

    virtual void updateBackground( KSharedPixmap * );

private slots:
//    void slotBackgroundChanged(int);
    void slotDone(bool);

private:
    bool m_bActive, m_bInit/*, m_bCustomPaint*/;
    int m_Desk;

//    double m_Fade;
//    TQColor m_FadeColor;

    TQRect m_Rect;
//    TQWidget *m_pWidget;
//    TQTimer *m_pTimer;
    KSharedPixmap *m_pPixmap;
//    KMyRootPixmapData *d;

    void init();
};

#endif // ! TQ_WS_TQWS
#endif // __KRootPixmap_h_Included__

==> r14.0.1.tar.gz: twin-style-crystal/client/myrootpixmap.h <==
/* vi: ts=8 sts=4 sw=4
 *
 * $Id: krootpixmap.h,v 1.15 2003/05/19 08:02:48 coolo Exp $
 * This file is part of the KDE project, module kdesktop.
 * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
 *
 * You can Freely distribute this program under the GNU Library General
 * Public License. See the file "COPYING.LIB" for the exact licensing terms.
 */

/* Modified by Sascha Hlusiak */
/* Further modified 11/18/2014 by Timothy Pearson <kb9vqf@pearsoncomputing.net> */

#ifndef __KRootPixmap_h_Included__
#define __KRootPixmap_h_Included__

#include <tqobject.h>
#include <tqwidget.h>
#include <tqcolor.h>

#ifndef TQ_WS_TQWS //FIXME

class TQRect;
class TQTimer;
class TDESharedPixmap;
class KMyRootPixmapData;

class DesktopWallpaperWatcher : public TQWidget
{
	Q_OBJECT

	public:
		DesktopWallpaperWatcher();
		~DesktopWallpaperWatcher();

		bool x11Event( XEvent * ev );

	signals:
		void currentDesktopChanged( int desktop);

	private:
		int m_old_current_desktop;
};

class KMyRootPixmap: public TQObject
{
    Q_OBJECT

public:
    KMyRootPixmap( TQWidget *target=NULL, const char *name=0 );

    KMyRootPixmap( TQWidget *target, TQObject *parent, const char *name=0 );

    virtual ~KMyRootPixmap();

    bool isAvailable();

    bool isActive() const { return m_bActive; }

    int currentDesktop() const;

//    bool customPainting() const { return m_bCustomPaint; }

#ifndef KDE_NO_COMPAT

    bool checkAvailable(bool) { return isAvailable(); }
#endif

public slots:
    virtual void start();

    virtual void stop();

//    void setFadeEffect(double strength, const TQColor &color);

    void repaint( bool force );

    void repaint();

//    void setCustomPainting( bool enable ) { m_bCustomPaint = enable; }

    void enableExports();

    static TQString pixmapName(int desk);
    
signals:
    void backgroundUpdated( const TQImage *pm );

protected:
//    virtual bool eventFilter(TQObject *, TQEvent *);

    virtual void updateBackground( TDESharedPixmap * );

private slots:
//    void slotBackgroundChanged(int);
    void slotDone(bool);
    void desktopChanged(int desktop);

private:
    bool m_bActive, m_bInit/*, m_bCustomPaint*/;
    int m_Desk;

//    double m_Fade;
//    TQColor m_FadeColor;

    TQRect m_Rect;
//    TQWidget *m_pWidget;
//    TQTimer *m_pTimer;
    TDESharedPixmap *m_pPixmap;
    KMyRootPixmapData *d;

    void init();
};

#endif // ! TQ_WS_TQWS
#endif // __KRootPixmap_h_Included__
